@@ -1,4 +1,4 @@
-#$Id: 31a146dc8bd9793b42016c0dd1d7ce754c8b3d2a $
+#$Id: Simple.pm,v 1.29 2008/01/01 16:34:15 sullivan Exp $
 #
 #	See the POD documentation starting towards the __END__ of this file.
 
@@ -8,7 +8,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = 'v1.2';
+our $VERSION = '1.1';
 
 use Scalar::Util qw(refaddr);
 use Carp;
@@ -602,7 +602,7 @@ and the values will be used to initialize its respective attribute.
 =item B<privatize(>qw(method1 method2 ...B<)>
 
 Mark the given methods as being private to the class.
-They will only be accessible to the class or its children.
+They will only be accessible to the class or its ancestors.
 Make sure this is called before you start instantiating objects.
 It should probably be put in a B<BEGIN> or B<INIT> block.
 
@@ -756,13 +756,9 @@ L<Storable>
 
 Michael Sullivan, E<lt>perldude@mac.comE<gt>
 
-=head1 REPOSITORY
-
-L<https://github.com/perldude/Class-Simple>
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007-2020 by Michael Sullivan
+Copyright (C) 2007 by Michael Sullivan
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
